@@ -6,7 +6,8 @@ from modeltranslation.settings import AVAILABLE_LANGUAGES
 from .views import CategoryDetailView, PageDetailView, SetLanguageView
 
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
 
     # Set language view
     url(r'^i18n/td_cms_set_language/',
@@ -21,7 +22,8 @@ for language_code in AVAILABLE_LANGUAGES:
     # resolution
     base_url = r'^%s/' % language_code
 
-    urlpatterns += patterns('',
+    urlpatterns += patterns(
+        '',
 
         # Category
         url(base_url + r'(?P<slug_%s>[-\w]+)/$' % language_code,
